#!/usr/bin/env python

import os
import re
from distutils.core import setup
from distutils.log import info, warn
from distutils.command.install_scripts import install_scripts
from tuxtremsplit.application import Application


class InstallScripts(install_scripts):
    """
    Create symbolic link /usr/[local/]bin/txs -> /usr/[local/]bin/tuxtremsplit
    """

    def run(self):
        install_scripts.run(self)
        create_symlink = True
        if re.match(".*tuxtremsplit-[\d.]*\d+.*/debian/.*", self.install_dir):
            warn("As you're not installing tuxtremsplit in standard path "
                 "(like /usr for example), I don't create the symbolic link.")
            create_symlink = False

        if create_symlink and os.path.exists(os.path.join(self.install_dir,
                                                          "tuxtremsplit")):
            warn("symbolic link already exists")
        else:
            info("creating symbolic link")
            os.symlink(os.path.join(self.install_dir, "txs"),
                       os.path.join(self.install_dir, "tuxtremsplit"))

setup(
    name = Application().settings.name,
    version = Application().settings.version,
    description = Application().settings.description,
    author = Application().settings.author,
    author_email = Application().settings.author_email,
    url = Application().settings.homepage,
    packages = [
        "tuxtremsplit",
        "tuxtremsplit.application",
        "tuxtremsplit.core"],
    scripts = ["txs"],
    data_files = [
        ("share/tuxtremsplit/config", ["config/settings.yml"]),
        ("share/tuxtremsplit/data", ["data/xtm_sfx-1.2.dump"])],
    cmdclass = {'install_scripts': InstallScripts})
